==> plugin-module-codegen-engine-9.0.0-sources.jar: com/atlassian/plugins/codegen/modules/common/servlet/ServletContextParameterModuleCreator.java <==
package com.atlassian.plugins.codegen.modules.common.servlet;

import com.atlassian.plugins.codegen.PluginProjectChangeset;
import com.atlassian.plugins.codegen.annotations.BambooPluginModuleCreator;
import com.atlassian.plugins.codegen.annotations.BitbucketPluginModuleCreator;
import com.atlassian.plugins.codegen.annotations.ConfluencePluginModuleCreator;
import com.atlassian.plugins.codegen.annotations.JiraPluginModuleCreator;
import com.atlassian.plugins.codegen.annotations.RefAppPluginModuleCreator;
import com.atlassian.plugins.codegen.modules.AbstractPluginModuleCreator;

import static com.atlassian.plugins.codegen.modules.Dependencies.SERVLET_API;

/**
 * @since 3.6
 */
@RefAppPluginModuleCreator
@JiraPluginModuleCreator
@ConfluencePluginModuleCreator
@BambooPluginModuleCreator
@BitbucketPluginModuleCreator
public class ServletContextParameterModuleCreator extends AbstractPluginModuleCreator<ServletContextParameterProperties> {
    public static final String MODULE_NAME = "Servlet Context Parameter";
    private static final String TEMPLATE_PREFIX = "templates/common/servlet/parameter/";

    private static final String PLUGIN_MODULE_TEMPLATE = TEMPLATE_PREFIX + "servlet-context-parameter-plugin.xml.vtl";

    @Override
    public PluginProjectChangeset createModule(ServletContextParameterProperties props) throws Exception {
        return new PluginProjectChangeset()
                .with(SERVLET_API)
                .with(createModule(props, PLUGIN_MODULE_TEMPLATE));
    }

    @Override
    public String getModuleName() {
        return MODULE_NAME;
    }
}

==> plugin-module-codegen-engine-9.3.2-sources.jar: com/atlassian/plugins/codegen/modules/common/servlet/ServletContextParameterModuleCreator.java <==
package com.atlassian.plugins.codegen.modules.common.servlet;

import static com.atlassian.plugins.codegen.modules.Dependencies.SERVLET_API;

import com.atlassian.plugins.codegen.PluginProjectChangeset;
import com.atlassian.plugins.codegen.annotations.BambooPluginModuleCreator;
import com.atlassian.plugins.codegen.annotations.BitbucketPluginModuleCreator;
import com.atlassian.plugins.codegen.annotations.ConfluencePluginModuleCreator;
import com.atlassian.plugins.codegen.annotations.JiraPluginModuleCreator;
import com.atlassian.plugins.codegen.annotations.RefAppPluginModuleCreator;
import com.atlassian.plugins.codegen.modules.AbstractPluginModuleCreator;

/** @since 3.6 */
@RefAppPluginModuleCreator
@JiraPluginModuleCreator
@ConfluencePluginModuleCreator
@BambooPluginModuleCreator
@BitbucketPluginModuleCreator
public class ServletContextParameterModuleCreator
        extends AbstractPluginModuleCreator<ServletContextParameterProperties> {
    public static final String MODULE_NAME = "Servlet Context Parameter";
    private static final String TEMPLATE_PREFIX = "templates/common/servlet/parameter/";

    private static final String PLUGIN_MODULE_TEMPLATE = TEMPLATE_PREFIX + "servlet-context-parameter-plugin.xml.vtl";

    @Override
    public PluginProjectChangeset createModule(ServletContextParameterProperties props) throws Exception {
        return new PluginProjectChangeset().with(SERVLET_API).with(createModule(props, PLUGIN_MODULE_TEMPLATE));
    }

    @Override
    public String getModuleName() {
        return MODULE_NAME;
    }
}
